# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#             PROCESS ANTARCTIC DIGITAL DATANASE DATA              #
#                                                                  #
####################################################################

This script is processing the Antarctic Digital Database (ADD) input
for the AWI Basemap. Input layers are the ADD coastlines and the ADD
rock outcrops. Both layers are reprojected to a global CRS
(EPSG_WORLD), coastlines are separated by shelf ice and ice sheet,
and all geometries are fixed (with zero buffer).

"""


#=============================================================================
#    SCRIPT INFO
#=============================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.1'
__date__ = '2020-12-17'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Developement'


#=============================================================================
#    IMPORT
#=============================================================================

import os

# import AWI Basemap configuration
from config import *


#=============================================================================
#    GLOBAL VARIABLES
#=============================================================================

# projection of ADD data
EPSG_ADD = 'EPSG:3031'


#=============================================================================
#    PROCESS
#=============================================================================

# layer names
add_coastline_in_name = os.path.splitext(os.path.basename(ADD_COASTLINE_IN))[0]
add_ice_sheet_name = os.path.splitext(os.path.basename(ADD_ICE_SHEET))[0]
add_shelf_ice_name = os.path.splitext(os.path.basename(ADD_SHELF_ICE))[0]
add_rock_outcrop_in_name = os.path.splitext(os.path.basename(ADD_ROCK_OUTCROP_IN))[0]
# inconsistancy with add 7.3 layer names, variable needs to be overwritten
add_rock_outcrop_in_name = 'add_rock_outcrop_medium_res_polygon_v7'
add_rock_outcrop_name = os.path.splitext(os.path.basename(ADD_ROCK_OUTCROP))[0]

# heading
print()
print('============================================================')
print('              ANTARCTIC DIGITAL DATANASE / ADD              ')


msg = 'Reprojecting and extracting land mask from ADD coastlines...'
cmd = f'ogr2ogr -s_srs {EPSG_ADD} -t_srs {EPSG_WORLD} -wrapdateline -nln "{add_ice_sheet_name}" -nlt  MULTIPOLYGON -f GPKG -overwrite {ADD_ICE_SHEET} {ADD_COASTLINE_IN} -dialect SQLite -sql "SELECT ST_Buffer(ST_Multi(geom),0.0) from \'{add_coastline_in_name}\' WHERE surface=\'land\'"'
run(msg,cmd)

msg = 'Reprojecting and extracting ice mask from ADD coastlines...'
cmd = f'ogr2ogr -s_srs {EPSG_ADD} -t_srs {EPSG_WORLD} -wrapdateline -nln "{add_shelf_ice_name}" -nlt  MULTIPOLYGON -f GPKG -overwrite {ADD_SHELF_ICE} {ADD_COASTLINE_IN} -dialect SQLite -sql "SELECT ST_Buffer(ST_Multi(geom),0.0) from \'{add_coastline_in_name}\' WHERE surface IN (\'ice shelf\',\'rumple\',\'ocean\',\'ice tongue\')"'
run(msg,cmd)

msg = 'Reprojecting ADD rock outcrops...'
cmd = f'ogr2ogr -s_srs {EPSG_ADD} -t_srs {EPSG_WORLD} -wrapdateline -nln "{add_rock_outcrop_name}" -nlt  MULTIPOLYGON -f GPKG -overwrite {ADD_ROCK_OUTCROP} {ADD_ROCK_OUTCROP_IN} -dialect SQLite -sql "SELECT ST_Buffer(ST_Multi(geom),0.0) from \'{add_rock_outcrop_in_name}\'"'
run(msg,cmd)
