# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#            PROCESS GREENLAND ICE MAPPING PROJECT DATA            #
#                                                                  #
####################################################################

This script is processing the Greenland Ice Mapping Project (GIMP)
input for the AWI Basemap. The raster is downsampled for easier data
handling and then polygonized to get a vector dataset.

"""


#=============================================================================
#    SCRIPT INFO
#=============================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.1'
__date__ = '2020-12-17'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Developement'


#=============================================================================
#    IMPORT
#=============================================================================

import os

# import AWI Basemap configuration
from config import *


#=============================================================================
#    PROCESS
#=============================================================================

# layer names
gimp_name = os.path.splitext(os.path.basename(GIMP))[0]

# heading
print()
print('============================================================')
print('            GREENLAND ICE MAPPING PROJECT / GIMP            ')

msg = 'Reprojecting and downsampling GIMP raster...'
cmd = f'gdalwarp -t_srs {EPSG_WORLD} -dstnodata 0.0 -tr {GIMP_RESOLUTION} {GIMP_RESOLUTION} -r near -of GTiff {GIMP_IN} {GIMP_RASTER}'
run(msg,cmd)

msg = 'Polygonizing GIMP raster...'
cmd = f'{PYTHON} -m gdal_polygonize {GIMP_RASTER} {GIMP} -b 1 -f "GPKG" {gimp_name} DN'
run(msg,cmd)

cleanup(GIMP_RASTER)
